=========================
 Aloe: Django extensions
=========================

`aloe_django` provides utilities to help write Aloe_ BDD tests for Django_
applications.

.. toctree::
    :maxdepth: 2

    harvest
    steps
    porting

Installing
==========

::

    pip install aloe_django

.. include:: using.rst

History
=======

`Aloe-Django` originally started life as part of the Python BDD tool Lettuce_.
Like so many succulents, it grew into so much more than that.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _aloe: https://github.com/aloetesting/aloe
.. _django: http://djangoproject.com/
.. _`django_nose`: https://github.com/django-nose/django-nose
.. _lettuce: http://lettuce.it/
